==> visual-third-party-0.0.2-whowho-sources.jar: com/tenqube/visual_third/model/js/Transactions.java <==
package com.tenqube.visual_third.model.js;

import android.content.Context;

import com.tenqube.visual_third.entity.JoinedTransaction;

import java.io.Serializable;
import java.util.ArrayList;

public class Transactions implements Serializable {

    private ArrayList<Transaction> transactions;

    public Transactions(ArrayList<Transaction> transactions) {
        this.transactions = transactions;
    }

    public static class Transaction implements Serializable {
        private int transactionId;
        private int categoryCode;
        private String largeCategory;
        private String mediumCategory;
        private int userCateConfigId;
        private int companyId;
        private String franchise;
        private int cardId;
        private String changeName;
        private double spentMoney;
        private int installmentCount;
        private int repeatType;
        private int exceptType;
        private int dwType;
        private String currency;
        private int isOffset;
        private String spentDate;
        private String finishDate;
        private String keyword;
        private String memo;
        private boolean isOwner;

        public Transaction(Context context, JoinedTransaction joinedTransaction) {
            this.transactionId = joinedTransaction.getTransaction().getId();
            this.categoryCode = joinedTransaction.getCategory().getCode();
            this.largeCategory = joinedTransaction.getCategory().getLarge();
            this.mediumCategory = joinedTransaction.getCategory().getMedium();
            this.userCateConfigId = joinedTransaction.getTransaction().getUserCategoryId();
            this.companyId = joinedTransaction.getTransaction().getCompanyId();
            this.franchise = joinedTransaction.getTransaction().getFranchise();
            this.cardId = joinedTransaction.getTransaction().getCardId();
            this.changeName = joinedTransaction.getCard().getChangeName();
            this.spentMoney = joinedTransaction.getTransaction().getSpentMoney();
            this.installmentCount = joinedTransaction.getTransaction().getInstallmentCnt();
            this.repeatType = joinedTransaction.getTransaction().getRepeatType();
            this.exceptType = joinedTransaction.getCard().isExcept() || joinedTransaction.getUserCategory().isExcept() ? 1 : 0;
            this.dwType = joinedTransaction.getTransaction().getDwType();
            this.currency = joinedTransaction.getTransaction().getCurrency();
            this.isOffset = joinedTransaction.getTransaction().isOffset() ? 1:0;
            this.spentDate = joinedTransaction.getTransaction().getSpentDate();
            this.finishDate = joinedTransaction.getTransaction().getFinishDate();
            this.keyword = joinedTransaction.getTransaction().getKeyword();
            this.memo = joinedTransaction.getTransaction().getMemo();
            this.isOwner = "com.lge.lgpay".equals(joinedTransaction.getTransaction().getSender());
//            this.isOwner = context.getApplicationContext().getPackageName().equals(joinedTransaction.getTransaction().getSender());
        }

        public String getKeyword() {
            return keyword;
        }

        public String getSpentDate() {
            return spentDate;
        }

        @Override
        public String toString() {
            return "Transaction{" +
                    "transactionId=" + transactionId +
                    ", categoryCode=" + categoryCode +
                    ", largeCategory='" + largeCategory + '\'' +
                    ", mediumCategory='" + mediumCategory + '\'' +
                    ", userCateConfigId=" + userCateConfigId +
                    ", companyId=" + companyId +
                    ", franchise='" + franchise + '\'' +
                    ", cardId=" + cardId +
                    ", changeName='" + changeName + '\'' +
                    ", spentMoney=" + spentMoney +
                    ", installmentCount=" + installmentCount +
                    ", repeatType=" + repeatType +
                    ", exceptType=" + exceptType +
                    ", dwType=" + dwType +
                    ", currency='" + currency + '\'' +
                    ", isOffset=" + isOffset +
                    ", spentDate='" + spentDate + '\'' +
                    ", finishDate='" + finishDate + '\'' +
                    ", keyword='" + keyword + '\'' +
                    ", memo='" + memo + '\'' +
                    '}';
        }
    }
}

==> visual-third-party-0.1.5-whowho-sources.jar: com/tenqube/visual_third/model/js/Transactions.java <==
package com.tenqube.visual_third.model.js;

import com.tenqube.visual_third.entity.JoinedTransaction;

import java.io.Serializable;
import java.util.ArrayList;

public class Transactions implements Serializable {

    private ArrayList<Transaction> transactions;

    public Transactions(ArrayList<Transaction> transactions) {
        this.transactions = transactions;
    }

    public static class Transaction implements Serializable {
        private int transactionId;
        private int categoryCode;
        private String largeCategory;
        private String mediumCategory;
        private int userCateConfigId;
        private int companyId;
        private String franchise;
        private int cardId;
        private String changeName;
        private double spentMoney;
        private int installmentCount;
        private int repeatType;
        private int exceptType;
        private int dwType;
        private String currency;
        private int isOffset;
        private String spentDate;
        private String finishDate;
        private String keyword;
        private String memo;

        public Transaction(JoinedTransaction joinedTransaction) {
            this.transactionId = joinedTransaction.getTransaction().getId();
            this.categoryCode = joinedTransaction.getCategory().getCode();
            this.largeCategory = joinedTransaction.getCategory().getLarge();
            this.mediumCategory = joinedTransaction.getCategory().getMedium();
            this.userCateConfigId = joinedTransaction.getTransaction().getUserCategoryId();
            this.companyId = joinedTransaction.getTransaction().getCompanyId();
            this.franchise = joinedTransaction.getTransaction().getFranchise();
            this.cardId = joinedTransaction.getTransaction().getCardId();
            this.changeName = joinedTransaction.getCard().getChangeName();
            this.spentMoney = joinedTransaction.getTransaction().getSpentMoney();
            this.installmentCount = joinedTransaction.getTransaction().getInstallmentCnt();
            this.repeatType = joinedTransaction.getTransaction().getRepeatType();
            this.exceptType = joinedTransaction.getCard().isExcept() || joinedTransaction.getUserCategory().isExcept() ? 1 : 0;
            this.dwType = joinedTransaction.getTransaction().getDwType();
            this.currency = joinedTransaction.getTransaction().getCurrency();
            this.isOffset = joinedTransaction.getTransaction().isOffset() ? 1:0;
            this.spentDate = joinedTransaction.getTransaction().getSpentDate();
            this.finishDate = joinedTransaction.getTransaction().getFinishDate();
            this.keyword = joinedTransaction.getTransaction().getKeyword();
            this.memo = joinedTransaction.getTransaction().getMemo();
        }


    }
}
